pub mod actions_add_custom_labels_to_self_hosted_runner_for_org;
pub mod actions_add_custom_labels_to_self_hosted_runner_for_repo;
pub mod actions_add_repo_access_to_self_hosted_runner_group_in_org;
pub mod actions_add_selected_repo_to_org_secret;
pub mod actions_add_self_hosted_runner_to_group_for_org;
pub mod actions_approve_workflow_run;
pub mod actions_cancel_workflow_run;
pub mod actions_create_or_update_environment_secret;
pub mod actions_create_or_update_org_secret;
pub mod actions_create_or_update_repo_secret;
pub mod actions_create_registration_token_for_org;
pub mod actions_create_registration_token_for_repo;
pub mod actions_create_remove_token_for_org;
pub mod actions_create_remove_token_for_repo;
pub mod actions_create_self_hosted_runner_group_for_org;
pub mod actions_create_workflow_dispatch;
pub mod actions_delete_artifact;
pub mod actions_delete_environment_secret;
pub mod actions_delete_org_secret;
pub mod actions_delete_repo_secret;
pub mod actions_delete_self_hosted_runner_from_org;
pub mod actions_delete_self_hosted_runner_from_repo;
pub mod actions_delete_self_hosted_runner_group_from_org;
pub mod actions_delete_workflow_run;
pub mod actions_delete_workflow_run_logs;
pub mod actions_disable_selected_repository_github_actions_organization;
pub mod actions_disable_workflow;
pub mod actions_download_artifact;
pub mod actions_download_job_logs_for_workflow_run;
pub mod actions_download_workflow_run_attempt_logs;
pub mod actions_download_workflow_run_logs;
pub mod actions_enable_selected_repository_github_actions_organization;
pub mod actions_enable_workflow;
pub mod actions_get_actions_cache_usage;
pub mod actions_get_actions_cache_usage_by_repo_for_org;
pub mod actions_get_actions_cache_usage_for_enterprise;
pub mod actions_get_actions_cache_usage_for_org;
pub mod actions_get_allowed_actions_organization;
pub mod actions_get_allowed_actions_repository;
pub mod actions_get_artifact;
pub mod actions_get_environment_public_key;
pub mod actions_get_environment_secret;
pub mod actions_get_github_actions_default_workflow_permissions_enterprise;
pub mod actions_get_github_actions_default_workflow_permissions_organization;
pub mod actions_get_github_actions_default_workflow_permissions_repository;
pub mod actions_get_github_actions_permissions_organization;
pub mod actions_get_github_actions_permissions_repository;
pub mod actions_get_job_for_workflow_run;
pub mod actions_get_org_public_key;
pub mod actions_get_org_secret;
pub mod actions_get_pending_deployments_for_run;
pub mod actions_get_repo_public_key;
pub mod actions_get_repo_secret;
pub mod actions_get_reviews_for_run;
pub mod actions_get_self_hosted_runner_for_org;
pub mod actions_get_self_hosted_runner_for_repo;
pub mod actions_get_self_hosted_runner_group_for_org;
pub mod actions_get_workflow;
pub mod actions_get_workflow_access_to_repository;
pub mod actions_get_workflow_run;
pub mod actions_get_workflow_run_attempt;
pub mod actions_get_workflow_run_usage;
pub mod actions_get_workflow_usage;
pub mod actions_list_artifacts_for_repo;
pub mod actions_list_environment_secrets;
pub mod actions_list_jobs_for_workflow_run;
pub mod actions_list_jobs_for_workflow_run_attempt;
pub mod actions_list_labels_for_self_hosted_runner_for_org;
pub mod actions_list_labels_for_self_hosted_runner_for_repo;
pub mod actions_list_org_secrets;
pub mod actions_list_repo_access_to_self_hosted_runner_group_in_org;
pub mod actions_list_repo_secrets;
pub mod actions_list_repo_workflows;
pub mod actions_list_runner_applications_for_org;
pub mod actions_list_runner_applications_for_repo;
pub mod actions_list_selected_repos_for_org_secret;
pub mod actions_list_selected_repositories_enabled_github_actions_organization;
pub mod actions_list_self_hosted_runner_groups_for_org;
pub mod actions_list_self_hosted_runners_for_org;
pub mod actions_list_self_hosted_runners_for_repo;
pub mod actions_list_self_hosted_runners_in_group_for_org;
pub mod actions_list_workflow_run_artifacts;
pub mod actions_list_workflow_runs;
pub mod actions_list_workflow_runs_for_repo;
pub mod actions_re_run_job_for_workflow_run;
pub mod actions_re_run_workflow;
pub mod actions_re_run_workflow_failed_jobs;
pub mod actions_remove_all_custom_labels_from_self_hosted_runner_for_org;
pub mod actions_remove_all_custom_labels_from_self_hosted_runner_for_repo;
pub mod actions_remove_custom_label_from_self_hosted_runner_for_org;
pub mod actions_remove_custom_label_from_self_hosted_runner_for_repo;
pub mod actions_remove_repo_access_to_self_hosted_runner_group_in_org;
pub mod actions_remove_selected_repo_from_org_secret;
pub mod actions_remove_self_hosted_runner_from_group_for_org;
pub mod actions_review_pending_deployments_for_run;
pub mod actions_set_allowed_actions_organization;
pub mod actions_set_allowed_actions_repository;
pub mod actions_set_custom_labels_for_self_hosted_runner_for_org;
pub mod actions_set_custom_labels_for_self_hosted_runner_for_repo;
pub mod actions_set_github_actions_default_workflow_permissions_enterprise;
pub mod actions_set_github_actions_default_workflow_permissions_organization;
pub mod actions_set_github_actions_default_workflow_permissions_repository;
pub mod actions_set_github_actions_permissions_organization;
pub mod actions_set_github_actions_permissions_repository;
pub mod actions_set_repo_access_to_self_hosted_runner_group_in_org;
pub mod actions_set_selected_repos_for_org_secret;
pub mod actions_set_selected_repositories_enabled_github_actions_organization;
pub mod actions_set_self_hosted_runners_in_group_for_org;
pub mod actions_set_workflow_access_to_repository;
pub mod actions_update_self_hosted_runner_group_for_org;
pub mod activity_check_repo_is_starred_by_authenticated_user;
pub mod activity_delete_repo_subscription;
pub mod activity_delete_thread_subscription;
pub mod activity_get_feeds;
pub mod activity_get_repo_subscription;
pub mod activity_get_thread;
pub mod activity_get_thread_subscription_for_authenticated_user;
pub mod activity_list_events_for_authenticated_user;
pub mod activity_list_notifications_for_authenticated_user;
pub mod activity_list_org_events_for_authenticated_user;
pub mod activity_list_public_events;
pub mod activity_list_public_events_for_repo_network;
pub mod activity_list_public_events_for_user;
pub mod activity_list_public_org_events;
pub mod activity_list_received_events_for_user;
pub mod activity_list_received_public_events_for_user;
pub mod activity_list_repo_events;
pub mod activity_list_repo_notifications_for_authenticated_user;
pub mod activity_list_repos_starred_by_authenticated_user;
pub mod activity_list_repos_starred_by_user;
pub mod activity_list_repos_watched_by_user;
pub mod activity_list_stargazers_for_repo;
pub mod activity_list_watched_repos_for_authenticated_user;
pub mod activity_list_watchers_for_repo;
pub mod activity_mark_notifications_as_read;
pub mod activity_mark_repo_notifications_as_read;
pub mod activity_mark_thread_as_read;
pub mod activity_set_repo_subscription;
pub mod activity_set_thread_subscription;
pub mod activity_star_repo_for_authenticated_user;
pub mod activity_unstar_repo_for_authenticated_user;
pub mod apps_add_repo_to_installation_for_authenticated_user;
pub mod apps_check_token;
pub mod apps_create_from_manifest;
pub mod apps_create_installation_access_token;
pub mod apps_delete_authorization;
pub mod apps_delete_installation;
pub mod apps_delete_token;
pub mod apps_get_authenticated;
pub mod apps_get_by_slug;
pub mod apps_get_installation;
pub mod apps_get_org_installation;
pub mod apps_get_repo_installation;
pub mod apps_get_subscription_plan_for_account;
pub mod apps_get_subscription_plan_for_account_stubbed;
pub mod apps_get_user_installation;
pub mod apps_get_webhook_config_for_app;
pub mod apps_get_webhook_delivery;
pub mod apps_list_accounts_for_plan;
pub mod apps_list_accounts_for_plan_stubbed;
pub mod apps_list_installation_repos_for_authenticated_user;
pub mod apps_list_installations;
pub mod apps_list_installations_for_authenticated_user;
pub mod apps_list_plans;
pub mod apps_list_plans_stubbed;
pub mod apps_list_repos_accessible_to_installation;
pub mod apps_list_subscriptions_for_authenticated_user;
pub mod apps_list_subscriptions_for_authenticated_user_stubbed;
pub mod apps_list_webhook_deliveries;
pub mod apps_redeliver_webhook_delivery;
pub mod apps_remove_repo_from_installation_for_authenticated_user;
pub mod apps_reset_token;
pub mod apps_revoke_installation_access_token;
pub mod apps_scope_token;
pub mod apps_suspend_installation;
pub mod apps_unsuspend_installation;
pub mod apps_update_webhook_config_for_app;
pub mod billing_get_github_actions_billing_ghe;
pub mod billing_get_github_actions_billing_org;
pub mod billing_get_github_actions_billing_user;
pub mod billing_get_github_advanced_security_billing_ghe;
pub mod billing_get_github_advanced_security_billing_org;
pub mod billing_get_github_packages_billing_ghe;
pub mod billing_get_github_packages_billing_org;
pub mod billing_get_github_packages_billing_user;
pub mod billing_get_shared_storage_billing_ghe;
pub mod billing_get_shared_storage_billing_org;
pub mod billing_get_shared_storage_billing_user;
pub mod checks_create;
pub mod checks_create_suite;
pub mod checks_get;
pub mod checks_get_suite;
pub mod checks_list_annotations;
pub mod checks_list_for_ref;
pub mod checks_list_for_suite;
pub mod checks_list_suites_for_ref;
pub mod checks_rerequest_run;
pub mod checks_rerequest_suite;
pub mod checks_set_suites_preferences;
pub mod checks_update;
pub mod code_scanning_delete_analysis;
pub mod code_scanning_get_alert;
pub mod code_scanning_get_analysis;
pub mod code_scanning_get_sarif;
pub mod code_scanning_list_alert_instances;
pub mod code_scanning_list_alerts_for_org;
pub mod code_scanning_list_alerts_for_repo;
pub mod code_scanning_list_recent_analyses;
pub mod code_scanning_update_alert;
pub mod code_scanning_upload_sarif;
pub mod codes_of_conduct_get_all_codes_of_conduct;
pub mod codes_of_conduct_get_conduct_code;
pub mod codespaces_add_repository_for_secret_for_authenticated_user;
pub mod codespaces_codespace_machines_for_authenticated_user;
pub mod codespaces_create_for_authenticated_user;
pub mod codespaces_create_or_update_repo_secret;
pub mod codespaces_create_or_update_secret_for_authenticated_user;
pub mod codespaces_create_with_pr_for_authenticated_user;
pub mod codespaces_create_with_repo_for_authenticated_user;
pub mod codespaces_delete_for_authenticated_user;
pub mod codespaces_delete_repo_secret;
pub mod codespaces_delete_secret_for_authenticated_user;
pub mod codespaces_export_for_authenticated_user;
pub mod codespaces_get_export_details_for_authenticated_user;
pub mod codespaces_get_for_authenticated_user;
pub mod codespaces_get_public_key_for_authenticated_user;
pub mod codespaces_get_repo_public_key;
pub mod codespaces_get_repo_secret;
pub mod codespaces_get_secret_for_authenticated_user;
pub mod codespaces_list_for_authenticated_user;
pub mod codespaces_list_in_repository_for_authenticated_user;
pub mod codespaces_list_repo_secrets;
pub mod codespaces_list_repositories_for_secret_for_authenticated_user;
pub mod codespaces_list_secrets_for_authenticated_user;
pub mod codespaces_remove_repository_for_secret_for_authenticated_user;
pub mod codespaces_repo_machines_for_authenticated_user;
pub mod codespaces_set_repositories_for_secret_for_authenticated_user;
pub mod codespaces_start_for_authenticated_user;
pub mod codespaces_stop_for_authenticated_user;
pub mod codespaces_update_for_authenticated_user;
pub mod dependabot_add_selected_repo_to_org_secret;
pub mod dependabot_create_or_update_org_secret;
pub mod dependabot_create_or_update_repo_secret;
pub mod dependabot_delete_org_secret;
pub mod dependabot_delete_repo_secret;
pub mod dependabot_get_org_public_key;
pub mod dependabot_get_org_secret;
pub mod dependabot_get_repo_public_key;
pub mod dependabot_get_repo_secret;
pub mod dependabot_list_org_secrets;
pub mod dependabot_list_repo_secrets;
pub mod dependabot_list_selected_repos_for_org_secret;
pub mod dependabot_remove_selected_repo_from_org_secret;
pub mod dependabot_set_selected_repos_for_org_secret;
pub mod dependency_graph_diff_range;
pub mod emojis_get;
pub mod enterprise_admin_add_custom_labels_to_self_hosted_runner_for_enterprise;
pub mod enterprise_admin_add_org_access_to_self_hosted_runner_group_in_enterprise;
pub mod enterprise_admin_add_self_hosted_runner_to_group_for_enterprise;
pub mod enterprise_admin_create_registration_token_for_enterprise;
pub mod enterprise_admin_create_remove_token_for_enterprise;
pub mod enterprise_admin_create_self_hosted_runner_group_for_enterprise;
pub mod enterprise_admin_delete_scim_group_from_enterprise;
pub mod enterprise_admin_delete_self_hosted_runner_from_enterprise;
pub mod enterprise_admin_delete_self_hosted_runner_group_from_enterprise;
pub mod enterprise_admin_delete_user_from_enterprise;
pub mod enterprise_admin_disable_selected_organization_github_actions_enterprise;
pub mod enterprise_admin_enable_selected_organization_github_actions_enterprise;
pub mod enterprise_admin_get_allowed_actions_enterprise;
pub mod enterprise_admin_get_audit_log;
pub mod enterprise_admin_get_github_actions_permissions_enterprise;
pub mod enterprise_admin_get_provisioning_information_for_enterprise_group;
pub mod enterprise_admin_get_provisioning_information_for_enterprise_user;
pub mod enterprise_admin_get_self_hosted_runner_for_enterprise;
pub mod enterprise_admin_get_self_hosted_runner_group_for_enterprise;
pub mod enterprise_admin_list_labels_for_self_hosted_runner_for_enterprise;
pub mod enterprise_admin_list_org_access_to_self_hosted_runner_group_in_enterprise;
pub mod enterprise_admin_list_provisioned_groups_enterprise;
pub mod enterprise_admin_list_provisioned_identities_enterprise;
pub mod enterprise_admin_list_runner_applications_for_enterprise;
pub mod enterprise_admin_list_selected_organizations_enabled_github_actions_enterprise;
pub mod enterprise_admin_list_self_hosted_runner_groups_for_enterprise;
pub mod enterprise_admin_list_self_hosted_runners_for_enterprise;
pub mod enterprise_admin_list_self_hosted_runners_in_group_for_enterprise;
pub mod enterprise_admin_provision_and_invite_enterprise_group;
pub mod enterprise_admin_provision_and_invite_enterprise_user;
pub mod enterprise_admin_remove_all_custom_labels_from_self_hosted_runner_for_enterprise;
pub mod enterprise_admin_remove_custom_label_from_self_hosted_runner_for_enterprise;
pub mod enterprise_admin_remove_org_access_to_self_hosted_runner_group_in_enterprise;
pub mod enterprise_admin_remove_self_hosted_runner_from_group_for_enterprise;
pub mod enterprise_admin_set_allowed_actions_enterprise;
pub mod enterprise_admin_set_custom_labels_for_self_hosted_runner_for_enterprise;
pub mod enterprise_admin_set_github_actions_permissions_enterprise;
pub mod enterprise_admin_set_information_for_provisioned_enterprise_group;
pub mod enterprise_admin_set_information_for_provisioned_enterprise_user;
pub mod enterprise_admin_set_org_access_to_self_hosted_runner_group_in_enterprise;
pub mod enterprise_admin_set_selected_organizations_enabled_github_actions_enterprise;
pub mod enterprise_admin_set_self_hosted_runners_in_group_for_enterprise;
pub mod enterprise_admin_update_attribute_for_enterprise_group;
pub mod enterprise_admin_update_attribute_for_enterprise_user;
pub mod enterprise_admin_update_self_hosted_runner_group_for_enterprise;
pub mod gists_check_is_starred;
pub mod gists_create;
pub mod gists_create_comment;
pub mod gists_delete;
pub mod gists_delete_comment;
pub mod gists_fork;
pub mod gists_get;
pub mod gists_get_comment;
pub mod gists_get_revision;
pub mod gists_list;
pub mod gists_list_comments;
pub mod gists_list_commits;
pub mod gists_list_for_user;
pub mod gists_list_forks;
pub mod gists_list_public;
pub mod gists_list_starred;
pub mod gists_star;
pub mod gists_unstar;
pub mod gists_update;
pub mod gists_update_comment;
pub mod git_create_blob;
pub mod git_create_commit;
pub mod git_create_ref;
pub mod git_create_tag;
pub mod git_create_tree;
pub mod git_delete_ref;
pub mod git_get_blob;
pub mod git_get_commit;
pub mod git_get_ref;
pub mod git_get_tag;
pub mod git_get_tree;
pub mod git_list_matching_refs;
pub mod git_update_ref;
pub mod gitignore_get_all_templates;
pub mod gitignore_get_template;
pub mod interactions_get_restrictions_for_authenticated_user;
pub mod interactions_get_restrictions_for_org;
pub mod interactions_get_restrictions_for_repo;
pub mod interactions_remove_restrictions_for_authenticated_user;
pub mod interactions_remove_restrictions_for_org;
pub mod interactions_remove_restrictions_for_repo;
pub mod interactions_set_restrictions_for_authenticated_user;
pub mod interactions_set_restrictions_for_org;
pub mod interactions_set_restrictions_for_repo;
pub mod issues_add_assignees;
pub mod issues_add_labels;
pub mod issues_check_user_can_be_assigned;
pub mod issues_create;
pub mod issues_create_comment;
pub mod issues_create_label;
pub mod issues_create_milestone;
pub mod issues_delete_comment;
pub mod issues_delete_label;
pub mod issues_delete_milestone;
pub mod issues_get;
pub mod issues_get_comment;
pub mod issues_get_event;
pub mod issues_get_label;
pub mod issues_get_milestone;
pub mod issues_list;
pub mod issues_list_assignees;
pub mod issues_list_comments;
pub mod issues_list_comments_for_repo;
pub mod issues_list_events;
pub mod issues_list_events_for_repo;
pub mod issues_list_events_for_timeline;
pub mod issues_list_for_authenticated_user;
pub mod issues_list_for_org;
pub mod issues_list_for_repo;
pub mod issues_list_labels_for_milestone;
pub mod issues_list_labels_for_repo;
pub mod issues_list_labels_on_issue;
pub mod issues_list_milestones;
pub mod issues_lock;
pub mod issues_remove_all_labels;
pub mod issues_remove_assignees;
pub mod issues_remove_label;
pub mod issues_set_labels;
pub mod issues_unlock;
pub mod issues_update;
pub mod issues_update_comment;
pub mod issues_update_label;
pub mod issues_update_milestone;
pub mod licenses_get;
pub mod licenses_get_all_commonly_used;
pub mod licenses_get_for_repo;
pub mod markdown_render;
pub mod markdown_render_raw;
pub mod meta_get;
pub mod meta_get_octocat;
pub mod meta_get_zen;
pub mod meta_root;
pub mod migrations_cancel_import;
pub mod migrations_delete_archive_for_authenticated_user;
pub mod migrations_delete_archive_for_org;
pub mod migrations_download_archive_for_org;
pub mod migrations_get_archive_for_authenticated_user;
pub mod migrations_get_commit_authors;
pub mod migrations_get_import_status;
pub mod migrations_get_large_files;
pub mod migrations_get_status_for_authenticated_user;
pub mod migrations_get_status_for_org;
pub mod migrations_list_for_authenticated_user;
pub mod migrations_list_for_org;
pub mod migrations_list_repos_for_authenticated_user;
pub mod migrations_list_repos_for_org;
pub mod migrations_map_commit_author;
pub mod migrations_set_lfs_preference;
pub mod migrations_start_for_authenticated_user;
pub mod migrations_start_for_org;
pub mod migrations_start_import;
pub mod migrations_unlock_repo_for_authenticated_user;
pub mod migrations_unlock_repo_for_org;
pub mod migrations_update_import;
pub mod oauth_authorizations_create_authorization;
pub mod oauth_authorizations_delete_authorization;
pub mod oauth_authorizations_delete_grant;
pub mod oauth_authorizations_get_authorization;
pub mod oauth_authorizations_get_grant;
pub mod oauth_authorizations_get_or_create_authorization_for_app;
pub mod oauth_authorizations_get_or_create_authorization_for_app_and_fingerprint;
pub mod oauth_authorizations_list_authorizations;
pub mod oauth_authorizations_list_grants;
pub mod oauth_authorizations_update_authorization;
pub mod orgs_block_user;
pub mod orgs_cancel_invitation;
pub mod orgs_check_blocked_user;
pub mod orgs_check_membership_for_user;
pub mod orgs_check_public_membership_for_user;
pub mod orgs_convert_member_to_outside_collaborator;
pub mod orgs_create_invitation;
pub mod orgs_create_webhook;
pub mod orgs_delete_webhook;
pub mod orgs_get;
pub mod orgs_get_audit_log;
pub mod orgs_get_membership_for_authenticated_user;
pub mod orgs_get_membership_for_user;
pub mod orgs_get_webhook;
pub mod orgs_get_webhook_config_for_org;
pub mod orgs_get_webhook_delivery;
pub mod orgs_list;
pub mod orgs_list_app_installations;
pub mod orgs_list_blocked_users;
pub mod orgs_list_custom_roles;
pub mod orgs_list_failed_invitations;
pub mod orgs_list_for_authenticated_user;
pub mod orgs_list_for_user;
pub mod orgs_list_invitation_teams;
pub mod orgs_list_members;
pub mod orgs_list_memberships_for_authenticated_user;
pub mod orgs_list_outside_collaborators;
pub mod orgs_list_pending_invitations;
pub mod orgs_list_public_members;
pub mod orgs_list_saml_sso_authorizations;
pub mod orgs_list_webhook_deliveries;
pub mod orgs_list_webhooks;
pub mod orgs_ping_webhook;
pub mod orgs_redeliver_webhook_delivery;
pub mod orgs_remove_member;
pub mod orgs_remove_membership_for_user;
pub mod orgs_remove_outside_collaborator;
pub mod orgs_remove_public_membership_for_authenticated_user;
pub mod orgs_remove_saml_sso_authorization;
pub mod orgs_set_membership_for_user;
pub mod orgs_set_public_membership_for_authenticated_user;
pub mod orgs_unblock_user;
pub mod orgs_update;
pub mod orgs_update_membership_for_authenticated_user;
pub mod orgs_update_webhook;
pub mod orgs_update_webhook_config_for_org;
pub mod packages_delete_package_for_authenticated_user;
pub mod packages_delete_package_for_org;
pub mod packages_delete_package_for_user;
pub mod packages_delete_package_version_for_authenticated_user;
pub mod packages_delete_package_version_for_org;
pub mod packages_delete_package_version_for_user;
pub mod packages_get_all_package_versions_for_package_owned_by_authenticated_user;
pub mod packages_get_all_package_versions_for_package_owned_by_org;
pub mod packages_get_all_package_versions_for_package_owned_by_user;
pub mod packages_get_package_for_authenticated_user;
pub mod packages_get_package_for_organization;
pub mod packages_get_package_for_user;
pub mod packages_get_package_version_for_authenticated_user;
pub mod packages_get_package_version_for_organization;
pub mod packages_get_package_version_for_user;
pub mod packages_list_packages_for_authenticated_user;
pub mod packages_list_packages_for_organization;
pub mod packages_list_packages_for_user;
pub mod packages_restore_package_for_authenticated_user;
pub mod packages_restore_package_for_org;
pub mod packages_restore_package_for_user;
pub mod packages_restore_package_version_for_authenticated_user;
pub mod packages_restore_package_version_for_org;
pub mod packages_restore_package_version_for_user;
pub mod projects_add_collaborator;
pub mod projects_create_card;
pub mod projects_create_column;
pub mod projects_create_for_authenticated_user;
pub mod projects_create_for_org;
pub mod projects_create_for_repo;
pub mod projects_delete;
pub mod projects_delete_card;
pub mod projects_delete_column;
pub mod projects_get;
pub mod projects_get_card;
pub mod projects_get_column;
pub mod projects_get_permission_for_user;
pub mod projects_list_cards;
pub mod projects_list_collaborators;
pub mod projects_list_columns;
pub mod projects_list_for_org;
pub mod projects_list_for_repo;
pub mod projects_list_for_user;
pub mod projects_move_card;
pub mod projects_move_column;
pub mod projects_remove_collaborator;
pub mod projects_update;
pub mod projects_update_card;
pub mod projects_update_column;
pub mod pulls_check_if_merged;
pub mod pulls_create;
pub mod pulls_create_reply_for_review_comment;
pub mod pulls_create_review;
pub mod pulls_create_review_comment;
pub mod pulls_delete_pending_review;
pub mod pulls_delete_review_comment;
pub mod pulls_dismiss_review;
pub mod pulls_get;
pub mod pulls_get_review;
pub mod pulls_get_review_comment;
pub mod pulls_list;
pub mod pulls_list_comments_for_review;
pub mod pulls_list_commits;
pub mod pulls_list_files;
pub mod pulls_list_requested_reviewers;
pub mod pulls_list_review_comments;
pub mod pulls_list_review_comments_for_repo;
pub mod pulls_list_reviews;
pub mod pulls_merge;
pub mod pulls_remove_requested_reviewers;
pub mod pulls_request_reviewers;
pub mod pulls_submit_review;
pub mod pulls_update;
pub mod pulls_update_branch;
pub mod pulls_update_review;
pub mod pulls_update_review_comment;
pub mod rate_limit_get;
pub mod reactions_create_for_commit_comment;
pub mod reactions_create_for_issue;
pub mod reactions_create_for_issue_comment;
pub mod reactions_create_for_pull_request_review_comment;
pub mod reactions_create_for_release;
pub mod reactions_create_for_team_discussion_comment_in_org;
pub mod reactions_create_for_team_discussion_comment_legacy;
pub mod reactions_create_for_team_discussion_in_org;
pub mod reactions_create_for_team_discussion_legacy;
pub mod reactions_delete_for_commit_comment;
pub mod reactions_delete_for_issue;
pub mod reactions_delete_for_issue_comment;
pub mod reactions_delete_for_pull_request_comment;
pub mod reactions_delete_for_release;
pub mod reactions_delete_for_team_discussion;
pub mod reactions_delete_for_team_discussion_comment;
pub mod reactions_list_for_commit_comment;
pub mod reactions_list_for_issue;
pub mod reactions_list_for_issue_comment;
pub mod reactions_list_for_pull_request_review_comment;
pub mod reactions_list_for_release;
pub mod reactions_list_for_team_discussion_comment_in_org;
pub mod reactions_list_for_team_discussion_comment_legacy;
pub mod reactions_list_for_team_discussion_in_org;
pub mod reactions_list_for_team_discussion_legacy;
pub mod repos_accept_invitation_for_authenticated_user;
pub mod repos_add_app_access_restrictions;
pub mod repos_add_collaborator;
pub mod repos_add_status_check_contexts;
pub mod repos_add_team_access_restrictions;
pub mod repos_add_user_access_restrictions;
pub mod repos_check_collaborator;
pub mod repos_check_vulnerability_alerts;
pub mod repos_codeowners_errors;
pub mod repos_compare_commits;
pub mod repos_create_autolink;
pub mod repos_create_commit_comment;
pub mod repos_create_commit_signature_protection;
pub mod repos_create_commit_status;
pub mod repos_create_deploy_key;
pub mod repos_create_deployment;
pub mod repos_create_deployment_status;
pub mod repos_create_dispatch_event;
pub mod repos_create_for_authenticated_user;
pub mod repos_create_fork;
pub mod repos_create_in_org;
pub mod repos_create_or_update_environment;
pub mod repos_create_or_update_file_contents;
pub mod repos_create_pages_site;
pub mod repos_create_release;
pub mod repos_create_tag_protection;
pub mod repos_create_using_template;
pub mod repos_create_webhook;
pub mod repos_decline_invitation_for_authenticated_user;
pub mod repos_delete;
pub mod repos_delete_access_restrictions;
pub mod repos_delete_admin_branch_protection;
pub mod repos_delete_an_environment;
pub mod repos_delete_autolink;
pub mod repos_delete_branch_protection;
pub mod repos_delete_commit_comment;
pub mod repos_delete_commit_signature_protection;
pub mod repos_delete_deploy_key;
pub mod repos_delete_deployment;
pub mod repos_delete_file;
pub mod repos_delete_invitation;
pub mod repos_delete_pages_site;
pub mod repos_delete_pull_request_review_protection;
pub mod repos_delete_release;
pub mod repos_delete_release_asset;
pub mod repos_delete_tag_protection;
pub mod repos_delete_webhook;
pub mod repos_disable_automated_security_fixes;
pub mod repos_disable_lfs_for_repo;
pub mod repos_disable_vulnerability_alerts;
pub mod repos_download_tarball_archive;
pub mod repos_download_zipball_archive;
pub mod repos_enable_automated_security_fixes;
pub mod repos_enable_lfs_for_repo;
pub mod repos_enable_vulnerability_alerts;
pub mod repos_generate_release_notes;
pub mod repos_get;
pub mod repos_get_access_restrictions;
pub mod repos_get_admin_branch_protection;
pub mod repos_get_all_environments;
pub mod repos_get_all_status_check_contexts;
pub mod repos_get_all_topics;
pub mod repos_get_apps_with_access_to_protected_branch;
pub mod repos_get_autolink;
pub mod repos_get_branch;
pub mod repos_get_branch_protection;
pub mod repos_get_clones;
pub mod repos_get_code_frequency_stats;
pub mod repos_get_collaborator_permission_level;
pub mod repos_get_combined_status_for_ref;
pub mod repos_get_commit;
pub mod repos_get_commit_activity_stats;
pub mod repos_get_commit_comment;
pub mod repos_get_commit_signature_protection;
pub mod repos_get_community_profile_metrics;
pub mod repos_get_content;
pub mod repos_get_contributors_stats;
pub mod repos_get_deploy_key;
pub mod repos_get_deployment;
pub mod repos_get_deployment_status;
pub mod repos_get_environment;
pub mod repos_get_latest_pages_build;
pub mod repos_get_latest_release;
pub mod repos_get_pages;
pub mod repos_get_pages_build;
pub mod repos_get_pages_health_check;
pub mod repos_get_participation_stats;
pub mod repos_get_pull_request_review_protection;
pub mod repos_get_punch_card_stats;
pub mod repos_get_readme;
pub mod repos_get_readme_in_directory;
pub mod repos_get_release;
pub mod repos_get_release_asset;
pub mod repos_get_release_by_tag;
pub mod repos_get_status_checks_protection;
pub mod repos_get_teams_with_access_to_protected_branch;
pub mod repos_get_top_paths;
pub mod repos_get_top_referrers;
pub mod repos_get_users_with_access_to_protected_branch;
pub mod repos_get_views;
pub mod repos_get_webhook;
pub mod repos_get_webhook_config_for_repo;
pub mod repos_get_webhook_delivery;
pub mod repos_list_autolinks;
pub mod repos_list_branches;
pub mod repos_list_branches_for_head_commit;
pub mod repos_list_collaborators;
pub mod repos_list_comments_for_commit;
pub mod repos_list_commit_comments_for_repo;
pub mod repos_list_commit_statuses_for_ref;
pub mod repos_list_commits;
pub mod repos_list_contributors;
pub mod repos_list_deploy_keys;
pub mod repos_list_deployment_statuses;
pub mod repos_list_deployments;
pub mod repos_list_for_authenticated_user;
pub mod repos_list_for_org;
pub mod repos_list_for_user;
pub mod repos_list_forks;
pub mod repos_list_invitations;
pub mod repos_list_invitations_for_authenticated_user;
pub mod repos_list_languages;
pub mod repos_list_pages_builds;
pub mod repos_list_public;
pub mod repos_list_pull_requests_associated_with_commit;
pub mod repos_list_release_assets;
pub mod repos_list_releases;
pub mod repos_list_tag_protection;
pub mod repos_list_tags;
pub mod repos_list_teams;
pub mod repos_list_webhook_deliveries;
pub mod repos_list_webhooks;
pub mod repos_merge;
pub mod repos_merge_upstream;
pub mod repos_ping_webhook;
pub mod repos_redeliver_webhook_delivery;
pub mod repos_remove_app_access_restrictions;
pub mod repos_remove_collaborator;
pub mod repos_remove_status_check_contexts;
pub mod repos_remove_status_check_protection;
pub mod repos_remove_team_access_restrictions;
pub mod repos_remove_user_access_restrictions;
pub mod repos_rename_branch;
pub mod repos_replace_all_topics;
pub mod repos_request_pages_build;
pub mod repos_set_admin_branch_protection;
pub mod repos_set_app_access_restrictions;
pub mod repos_set_status_check_contexts;
pub mod repos_set_team_access_restrictions;
pub mod repos_set_user_access_restrictions;
pub mod repos_test_push_webhook;
pub mod repos_transfer;
pub mod repos_update;
pub mod repos_update_branch_protection;
pub mod repos_update_commit_comment;
pub mod repos_update_information_about_pages_site;
pub mod repos_update_invitation;
pub mod repos_update_pull_request_review_protection;
pub mod repos_update_release;
pub mod repos_update_release_asset;
pub mod repos_update_status_check_protection;
pub mod repos_update_webhook;
pub mod repos_update_webhook_config_for_repo;
pub mod repos_upload_release_asset;
pub mod scim_delete_user_from_org;
pub mod scim_get_provisioning_information_for_user;
pub mod scim_list_provisioned_identities;
pub mod scim_provision_and_invite_user;
pub mod scim_set_information_for_provisioned_user;
pub mod scim_update_attribute_for_user;
pub mod search_code;
pub mod search_commits;
pub mod search_issues_and_pull_requests;
pub mod search_labels;
pub mod search_repos;
pub mod search_topics;
pub mod search_users;
pub mod secret_scanning_get_alert;
pub mod secret_scanning_list_alerts_for_enterprise;
pub mod secret_scanning_list_alerts_for_org;
pub mod secret_scanning_list_alerts_for_repo;
pub mod secret_scanning_list_locations_for_alert;
pub mod secret_scanning_update_alert;
pub mod teams_add_member_legacy;
pub mod teams_add_or_update_membership_for_user_in_org;
pub mod teams_add_or_update_membership_for_user_legacy;
pub mod teams_add_or_update_project_permissions_in_org;
pub mod teams_add_or_update_project_permissions_legacy;
pub mod teams_add_or_update_repo_permissions_in_org;
pub mod teams_add_or_update_repo_permissions_legacy;
pub mod teams_check_permissions_for_project_in_org;
pub mod teams_check_permissions_for_project_legacy;
pub mod teams_check_permissions_for_repo_in_org;
pub mod teams_check_permissions_for_repo_legacy;
pub mod teams_create;
pub mod teams_create_discussion_comment_in_org;
pub mod teams_create_discussion_comment_legacy;
pub mod teams_create_discussion_in_org;
pub mod teams_create_discussion_legacy;
pub mod teams_create_or_update_idp_group_connections_in_org;
pub mod teams_create_or_update_idp_group_connections_legacy;
pub mod teams_delete_discussion_comment_in_org;
pub mod teams_delete_discussion_comment_legacy;
pub mod teams_delete_discussion_in_org;
pub mod teams_delete_discussion_legacy;
pub mod teams_delete_in_org;
pub mod teams_delete_legacy;
pub mod teams_external_idp_group_info_for_org;
pub mod teams_get_by_name;
pub mod teams_get_discussion_comment_in_org;
pub mod teams_get_discussion_comment_legacy;
pub mod teams_get_discussion_in_org;
pub mod teams_get_discussion_legacy;
pub mod teams_get_legacy;
pub mod teams_get_member_legacy;
pub mod teams_get_membership_for_user_in_org;
pub mod teams_get_membership_for_user_legacy;
pub mod teams_link_external_idp_group_to_team_for_org;
pub mod teams_list;
pub mod teams_list_child_in_org;
pub mod teams_list_child_legacy;
pub mod teams_list_discussion_comments_in_org;
pub mod teams_list_discussion_comments_legacy;
pub mod teams_list_discussions_in_org;
pub mod teams_list_discussions_legacy;
pub mod teams_list_external_idp_groups_for_org;
pub mod teams_list_for_authenticated_user;
pub mod teams_list_idp_groups_for_legacy;
pub mod teams_list_idp_groups_for_org;
pub mod teams_list_idp_groups_in_org;
pub mod teams_list_linked_external_idp_groups_to_team_for_org;
pub mod teams_list_members_in_org;
pub mod teams_list_members_legacy;
pub mod teams_list_pending_invitations_in_org;
pub mod teams_list_pending_invitations_legacy;
pub mod teams_list_projects_in_org;
pub mod teams_list_projects_legacy;
pub mod teams_list_repos_in_org;
pub mod teams_list_repos_legacy;
pub mod teams_remove_member_legacy;
pub mod teams_remove_membership_for_user_in_org;
pub mod teams_remove_membership_for_user_legacy;
pub mod teams_remove_project_in_org;
pub mod teams_remove_project_legacy;
pub mod teams_remove_repo_in_org;
pub mod teams_remove_repo_legacy;
pub mod teams_unlink_external_idp_group_from_team_for_org;
pub mod teams_update_discussion_comment_in_org;
pub mod teams_update_discussion_comment_legacy;
pub mod teams_update_discussion_in_org;
pub mod teams_update_discussion_legacy;
pub mod teams_update_in_org;
pub mod teams_update_legacy;
pub mod users_add_email_for_authenticated_user;
pub mod users_block;
pub mod users_check_blocked;
pub mod users_check_following_for_user;
pub mod users_check_person_is_followed_by_authenticated;
pub mod users_create_gpg_key_for_authenticated_user;
pub mod users_create_public_ssh_key_for_authenticated_user;
pub mod users_delete_email_for_authenticated_user;
pub mod users_delete_gpg_key_for_authenticated_user;
pub mod users_delete_public_ssh_key_for_authenticated_user;
pub mod users_follow;
pub mod users_get_authenticated;
pub mod users_get_by_username;
pub mod users_get_context_for_user;
pub mod users_get_gpg_key_for_authenticated_user;
pub mod users_get_public_ssh_key_for_authenticated_user;
pub mod users_list;
pub mod users_list_blocked_by_authenticated_user;
pub mod users_list_emails_for_authenticated_user;
pub mod users_list_followed_by_authenticated_user;
pub mod users_list_followers_for_authenticated_user;
pub mod users_list_followers_for_user;
pub mod users_list_following_for_user;
pub mod users_list_gpg_keys_for_authenticated_user;
pub mod users_list_gpg_keys_for_user;
pub mod users_list_public_emails_for_authenticated_user;
pub mod users_list_public_keys_for_user;
pub mod users_list_public_ssh_keys_for_authenticated_user;
pub mod users_set_primary_email_visibility_for_authenticated_user;
pub mod users_unblock;
pub mod users_unfollow;
pub mod users_update_authenticated;
